### Name: luca
### Title: Likelihood-based case-control inference Under Covariate
###   Assumptions (LUCA)
### Aliases: luca
### Keywords: methods

### ** Examples

data(lucaDat)
# typical penetrance model:
pen.model<-formula(d~I(allele.count(g,"C"))+a+a2+I(allele.count(g,"C")):a)

#1. Assuming independence and HWP       
fitHWP<-luca(pen.model=pen.model, gLabel="g", dat=lucaDat, HWP=TRUE)
fitHWP$coef
fitHWP$var
summary.luca(fitHWP) # OR 'summary(fitHWP)'

#2. Assuming independence only
fitDefault<-luca(pen.model=pen.model, gLabel="g", dat=lucaDat)
fitDefault$coef
fitDefault$var

#3. Allowing for dependence between genetic and nongenetic factors

# General dependence model
fitDep1<-luca(pen.model=pen.model, gLabel="g", dat=lucaDat, 
 dep.model=formula(g~a))
fitDep1$coef
fitDep1$var

# When 'g' and 'a' are conditioanally independent given the third variable 'a2':
fitDep2<-luca(pen.model=pen.model, gLabel="g", dat=lucaDat,
 dep.model=formula(g~a2))
fitDep2$coef
fitDep2$var



